==> financial-settlement-client-0.1.254-sources.jar: com/xforceplus/financialsettlement/controller/ReturnMoneyRecordViewFeignApi.java <==
package com.xforceplus.financialsettlement.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-09-08
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.financialsettlement.entity.ReturnMoneyRecordView;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "financial-settlement")
public interface ReturnMoneyRecordViewFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/returnMoneyRecordView/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param returnMoneyRecordView ${table.comment}
   * @return R
   */
  @PostMapping("/returnMoneyRecordView/add")
  public R save(@RequestBody ReturnMoneyRecordView returnMoneyRecordView);

  /**
   * 修改${table.comment}
   * @param returnMoneyRecordView ${table.comment}
   * @return R
   */
  @PostMapping("/returnMoneyRecordView/update")
  public R updateById(@RequestBody ReturnMoneyRecordView returnMoneyRecordView);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/returnMoneyRecordView/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> financial-settlement-client-0.1.314-sources.jar: com/xforceplus/financialsettlement/controller/ReturnMoneyRecordViewFeignApi.java <==
package com.xforceplus.financialsettlement.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2023-01-09
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.financialsettlement.entity.ReturnMoneyRecordView;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "financial-settlement")
public interface ReturnMoneyRecordViewFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/returnMoneyRecordView/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param returnMoneyRecordView ${table.comment}
   * @return R
   */
  @PostMapping("/returnMoneyRecordView/add")
  public R save(@RequestBody ReturnMoneyRecordView returnMoneyRecordView);

  /**
   * 修改${table.comment}
   * @param returnMoneyRecordView ${table.comment}
   * @return R
   */
  @PostMapping("/returnMoneyRecordView/update")
  public R updateById(@RequestBody ReturnMoneyRecordView returnMoneyRecordView);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/returnMoneyRecordView/del/{id}" )
  public R removeById(@PathVariable Long id);

}
